@@ -32,30 +32,36 @@ from typing import Iterable, Mapping, Optional, Sequence
 
 # 3rd party
 import click
-import isort  # type: ignore
+import isort
 from consolekit.terminal_colours import ColourTrilean, resolve_color_default
 from consolekit.utils import coloured_diff
 from domdf_python_tools.paths import PathPlus, TemporaryPathPlus
 from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.typing import PathLike
 from domdf_python_tools.words import TAB
-from isort.exceptions import FileSkipComment  # type: ignore
+from isort.exceptions import FileSkipComment
 
 # this package
 from formate.classes import FormateConfigDict, Hook
 from formate.config import parse_hooks, wants_filename, wants_global_config
 from formate.utils import syntaxerror_for_file
 
-__all__ = ["call_hooks", "isort_hook", "yapf_hook", "Reformatter", "reformat_file"]
-
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020-2021 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.4.2"
+__version__: str = "0.4.8"
 __email__: str = "dominic@davis-foster.co.uk"
 
+__all__ = ["call_hooks", "reformat_file", "Reformatter", "isort_hook", "yapf_hook"]
+
 # TODO: Ideas for hooks
 # * https://github.com/asottile/add-trailing-comma
+# * Replace collections imports with their typing equivalents where possible.
+# * nested with block reformat, dependent on linelength
+# * replace typing imports with typing_extensions where necessary. Needs min version flag
+# * replace e.g `import numpy as np` with `import numpy` and update all usages
+# * replace wildcard import with the things what is imported
+# * replace `exit()` with `sys.exit()` and add import if required
 
 
 def call_hooks(hooks: Iterable[Hook], source: str, filename: PathLike) -> str:
@@ -68,7 +74,7 @@ def call_hooks(hooks: Iterable[Hook], source: str, filename: PathLike) -> str:
 
 	:returns: The reformatted source.
 
-	.. versionchanged:: 0.4.2  Added the ``filename`` argument.
+	.. versionchanged:: 0.4.3  Added the ``filename`` argument.
 	"""
 
 	for hook in hooks:
@@ -129,7 +135,8 @@ def isort_hook(
 		isort_config = isort.Config(settings_file=str(kwargs["isort_config_file"]))
 	else:
 		if "line_length" not in kwargs and formate_global_config:
-			kwargs["line_length"] = formate_global_config["line_length"]
+			if "line_length" in (formate_global_config or {}):
+				kwargs["line_length"] = formate_global_config["line_length"]
 
 		parsed_kwargs = {}
 		import_headings = {}
@@ -183,10 +190,12 @@ def yapf_hook(source: str, formate_global_config: Optional[Mapping] = None, **kw
 
 	else:
 		if "use_tabs" not in kwargs and formate_global_config:
-			kwargs["use_tabs"] = formate_global_config["indent"] == TAB
+			if "indent" in (formate_global_config or {}):
+				kwargs["use_tabs"] = formate_global_config["indent"] == TAB
 
 		if "column_limit" not in kwargs and formate_global_config:
-			kwargs["column_limit"] = formate_global_config["line_length"]
+			if "line_length" in (formate_global_config or {}):
+				kwargs["column_limit"] = formate_global_config["line_length"]
 
 		with TemporaryPathPlus() as tmpdir:
 			config_file = tmpdir / ".style.yapf"
@@ -206,12 +215,14 @@ class Reformatter:
 
 	:param filename: The filename to reformat.
 	:param config: The ``formate`` configuration, parsed from a TOML file (or similar).
+
+	.. autosummary-widths:: 5/16 11/16
 	"""
 
 	#: The filename being reformatted.
 	filename: str
 
-	#: The filename being reformatted.
+	#: The filename being reformatted, as a POSIX-style path.
 	file_to_format: PathPlus
 
 	#: The ``formate`` configuration, parsed from a TOML file (or similar).
@@ -262,6 +273,10 @@ class Reformatter:
 	def to_string(self) -> str:
 		"""
 		Return the reformatted file as a string.
+
+		:rtype:
+
+		.. latex:clearpage::
 		"""
 
 		if self._reformatted_source is None:
@@ -288,6 +303,8 @@ def reformat_file(
 	:param filename: The filename to reformat.
 	:param config: The ``formate`` configuration, parsed from a TOML file (or similar).
 	:param colour: Whether to force coloured output on (:py:obj:`True`) or off (:py:obj:`False`).
+
+	.. latex:clearpage::
 	"""
 
 	r = Reformatter(filename, config)
@@ -297,7 +314,6 @@ def reformat_file(
 
 	if ret:
 		click.echo(r.get_diff(), color=resolve_color_default(colour))
-
-	r.to_file()
+		r.to_file()
 
 	return ret
