@@ -29,18 +29,19 @@ Read and parse formate configuration.
 # stdlib
 from operator import attrgetter
 from types import MappingProxyType
-from typing import Callable, List, Mapping, cast
+from typing import Callable, List, Mapping, TypeVar
 
 # 3rd party
-import toml
-from domdf_python_tools.paths import PathPlus
+import dom_toml
 from domdf_python_tools.typing import PathLike
 
 # this package
 from formate.classes import FormateConfigDict, Hook
 from formate.utils import import_entry_points
 
-__all__ = ["parse_hooks", "parse_global_config", "load_toml", "wants_global_config", "wants_filename"]
+__all__ = ["parse_hooks", "parse_global_config", "load_toml", "wants_global_config", "wants_filename", "_C_str"]
+
+_C_str = TypeVar("_C_str", bound=Callable[..., str])
 
 
 def parse_hooks(config: Mapping) -> List[Hook]:
@@ -48,6 +49,10 @@ def parse_hooks(config: Mapping) -> List[Hook]:
 	Given a mapping parsed from a TOML file (or similar), return a list of hooks selected by the user.
 
 	:param config: The ``formate`` configuration, parsed from a TOML file (or similar).
+
+	:rtype:
+
+	.. latex:clearpage::
 	"""
 
 	hooks = list(Hook.parse(config["hooks"]))
@@ -80,13 +85,13 @@ def load_toml(filename: PathLike) -> FormateConfigDict:
 	:param filename:
 	"""
 
-	formate_config: FormateConfigDict = {}
+	config = dom_toml.load(filename)
 
-	config = toml.loads(PathPlus(filename).read_text())
-
-	if "tool" in config and "formate" in config["tool"]:
+	if "formate" in config.get("tool", {}):
 		config = config["tool"]["formate"]
 
+	formate_config: FormateConfigDict = {}
+
 	if "hooks" in config:
 		formate_config["hooks"] = config["hooks"]
 	if "config" in config:
@@ -95,7 +100,7 @@ def load_toml(filename: PathLike) -> FormateConfigDict:
 	return formate_config
 
 
-def wants_global_config(func: Callable[..., str]) -> Callable[..., str]:
+def wants_global_config(func: _C_str) -> _C_str:
 	"""
 	Decorator to indicate to ``formate`` that the global configuration should be passed to this hook.
 
@@ -108,12 +113,12 @@ def wants_global_config(func: Callable[..., str]) -> Callable[..., str]:
 	return func
 
 
-def wants_filename(func: Callable[..., str]) -> Callable[..., str]:
+def wants_filename(func: _C_str) -> _C_str:
 	"""
 	Decorator to indicate to ``formate`` that the filename being reformatted should be passed to this hook.
 
 	The configuration will be provided as the
-	``formate_filename``: :class:`~domdf_python_tools.typing.PathLike` keyword argument.
+	``formate_filename``: :py:obj:`~domdf_python_tools.typing.PathLike` keyword argument.
 
 	.. versionadded:: 0.2.0
 
